<?php
/*
Plugin Name: Page List Widget
Plugin URI: http://www.nigauri.me/tech/wordpress/plubin_page_list_widget
Description: This is a widget plugin. This widget will display a list of pages.
Author: nigauri
Version: 1.0.0
Author URI: http://www.nigauri.me/
*/

define("PAGES_LIST_WIDGET_DOMAIN", "page-list-widget");

load_plugin_textdomain(PAGES_LIST_WIDGET_DOMAIN, false, basename( dirname( __FILE__ ) ) . '/languages' );

add_action(
	'widgets_init',
	create_function('', 'return register_widget("PageListWidget");')
);

class PageListWidget extends WP_Widget {

	function __construct() {
		$widget_ops = array('description' => __("This widget will display a list of pages.", PAGES_LIST_WIDGET_DOMAIN));
		parent::__construct(
			false,
			__("Page list", PAGES_LIST_WIDGET_DOMAIN),
			$widget_ops
		);
	}

	function form( $instance ) {
		$instance = wp_parse_args(
			(array) $instance,
			array(
				'title'     => '',
				'number'    => '5',
				'sort_col'  => 'post_modified',
				'asc_desc'  => 'desc',
				'exclude'   => '',
				'include'   => '',
				'show_date' => '1'
			)
		);

		$title     = strip_tags($instance['title']);
		$number    = strip_tags($instance['number']);
		$sort_col  = strip_tags($instance['sort_col']);
		$asc_desc  = strip_tags($instance['asc_desc']);
		$exclude   = strip_tags($instance['exclude']);
		$include   = strip_tags($instance['include']);
		$show_date = strip_tags($instance['show_date']);
?>
		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>">
				<?php _e('Title:', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('number'); ?>">
				<?php _e('Number of pages:', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
			<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo esc_attr($number); ?>" size="3" />
		</p>

		<p>
			<input id="<?php echo $this->get_field_id('show_date'); ?>" name="<?php echo $this->get_field_name('show_date'); ?>" type="checkbox" value="1" <?php echo $show_date == "1" ? "checked" : ""; ?> />
			<label for="<?php echo $this->get_field_id('show_date'); ?>">
				<?php _e('Display update date', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('sort_col'); ?>">
				<?php _e('Order by:', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
			<select id="<?php echo $this->get_field_id('sort_col'); ?>" name="<?php echo $this->get_field_name('sort_col'); ?>">
				<option value="post_title" <?php echo $sort_col == "post_title" ? "selected" : ""; ?>><?php _e('Title', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="menu_order" <?php echo $sort_col == "menu_order" ? "selected" : ""; ?>><?php _e('Menu order', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="post_date" <?php echo $sort_col == "post_date" ? "selected" : ""; ?>><?php _e('Post date', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="post_modified" <?php echo $sort_col == "post_modified" ? "selected" : ""; ?>><?php _e('Modified date', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="ID" <?php echo $sort_col == "ID" ? "selected" : ""; ?>><?php _e('ID', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="post_author" <?php echo $sort_col == "post_author" ? "selected" : ""; ?>><?php _e('Author', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="post_name" <?php echo $sort_col == "post_name" ? "selected" : ""; ?>><?php _e('Post name', PAGES_LIST_WIDGET_DOMAIN); ?></option>
			</select>
			<select id="<?php echo $this->get_field_id('asc_desc'); ?>" name="<?php echo $this->get_field_name('asc_desc'); ?>">
				<option value="asc" <?php echo $asc_desc == "asc" ? "selected" : ""; ?>><?php _e('Asc', PAGES_LIST_WIDGET_DOMAIN); ?></option>
				<option value="desc" <?php echo $asc_desc == "desc" ? "selected" : ""; ?>><?php _e('Desc', PAGES_LIST_WIDGET_DOMAIN); ?></option>
			</select>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('include'); ?>">
				<?php _e('Include pages:', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id('include'); ?>" name="<?php echo $this->get_field_name('include'); ?>" type="text" value="<?php echo esc_attr($include); ?>" />
			<small><?php _e('Page IDs, separated by commas.', PAGES_LIST_WIDGET_DOMAIN); ?></small>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('exclude'); ?>">
				<?php _e('Exclude pages:', PAGES_LIST_WIDGET_DOMAIN); ?>
			</label>
			<input class="widefat" id="<?php echo $this->get_field_id('exclude'); ?>" name="<?php echo $this->get_field_name('exclude'); ?>" type="text" value="<?php echo esc_attr($exclude); ?>" />
			<small><?php _e('Page IDs, separated by commas.', PAGES_LIST_WIDGET_DOMAIN); ?></small>
		</p>

<?php
	}

	public function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title']     = strip_tags($new_instance['title']);
		$instance['number']    = strip_tags($new_instance['number']);
		$instance['sort_col']  = strip_tags($new_instance['sort_col']);
		$instance['asc_desc']  = strip_tags($new_instance['asc_desc']);
		$instance['exclude']   = strip_tags($new_instance['exclude']);
		$instance['include']   = strip_tags($new_instance['include']);
		$instance['show_date'] = strip_tags($new_instance['show_date']);
		return $instance;
	}

	function widget( $args, $instance ) {
		extract($args);
		$title = apply_filters('widget_title', empty($instance['title']) ? __('Page list', PAGES_LIST_WIDGET_DOMAIN) : $instance['title'], $instance, $this->id_base);

		echo $before_widget;
		if ( $title )
			echo $before_title . $title . $after_title;
?>

<ul>

<?php

$args = array(
	'child_of'     => '',
	'sort_order'   => empty($instance['asc_desc']) ? "desc" : $instance['asc_desc'],
	'sort_column'  => empty($instance['sort_col']) ? "post_modified" : $instance['sort_col'],
	'hierarchical' => 0,
	'exclude'      => $instance['exclude'],
	'include'      => $instance['include'],
	'meta_key'     => '',
	'meta_value'   => '',
	'authors'      => '',
	'parent'       => -1,
	'exclude_tree' => '',
	'number'       => empty($instance['number']) ? 5 : $instance['number'],
	'offset'       => 0,
	'post_type'    => 'page',
	'post_status'  => 'publish'
);

$pages = get_pages($args);

foreach ($pages as $page) {
	$li = "<li><a href=\"" . get_page_link($page->ID) . "\" title=\"" . $page->post_title . "\">";
	$li .= $page->post_title;
	$li .= "</a>";

	if (!empty($instance['show_date'])) {
		$li .= "<span class=\"post-date\">";
		$li .= mysql2date(get_option('date_format'), $page->post_modified);
		$li .= "</span>";
	}

	$li .= '</li>';
	echo $li;
}

?>

</ul>

<?php
		echo $after_widget;
	}

}

?>